#!/bin/bash
#241211 totiks
#241214 sfs
# Путь для конфигурации zramswap
CONFIG_FILE="/etc/default/zramswap"

# Установить умолчания
DEFAULT_ALGO="lzo"
DEFAULT_PERCENT="30"
DEFAULT_PRIORITY="100"

# Функция для загрузки текущих значений конфигурации
load_zram_config() {
    if [[ -f "$CONFIG_FILE" ]]; then
        source "$CONFIG_FILE"
    fi

    # Устанавливаем значения по умолчанию, если переменные пусты
    ALGO="${ALGO:-$DEFAULT_ALGO}"
    PERCENT="${PERCENT:-$DEFAULT_PERCENT}"
    PRIORITY="${PRIORITY:-$DEFAULT_PRIORITY}"
}

# Загрузка текущей конфигурации
load_zram_config

# Диалог с параметрами
#aa="qq qq"
#systemctl is-active zramswap  || y1=--button=Старт!gtk-media-play!"${aa}":2
systemctl is-active zramswap  || y1='--button=Старт!gtk-media-play!systemctl_start_zramswap.service:2'
#systemctl is-active zramswap  || y1=--button=Старт!gtk-media-play!'systemctl start_zramswap.service':2
systemctl is-active zramswap  && y2='--button=Стoп!gtk-media-stop!"systemctl_stop_zramswap.service":4'
systemctl is-enabled zramswap || y3='--button=ВКЛ!gtk-add!"systemctl_enable_zramswap.service":6'
systemctl is-enabled zramswap && y4='--button=ВЫКЛ!gtk-remove!"systemctl_disable_zramswap.service":8  '

yad_output=$(yad --mouse --form --title="Swap in Zram" \
    --fixed --image-on-top \
    --text="<b>Swap на RAM-диске zram со сжатием на лету</b>
При малом количестве RAM - устанавливайте 150%

<span font='Mono' size='small'>
`free -hL`

`swapon`

`zramctl`

`systemctl status zramswap |sed 's/<//g'`
</span>" \
    --image=swap --window-icon=/usr/share/pixmaps/swap.png --name=swap \
    --field="										Алгоритм сжатия!max speed: lz4 > zstd > lzo
max compression: zstd > lzo > lz4:CB" "${ALGO}!lz4!lzo!zstd" \
    --field="										Выделяемый % памяти!Объем RAM для ZRAM в виде процентного соотношения к общему объему RAM:NUM" "${PERCENT}:1:100:1:0" \
    --field="										Приоритет!Большее число = более высокий приоритет. Должен быть выше, чем у swap на hdd/ssd.:NUM" "${PRIORITY}:1:1000:1" \
    $y1  \
    $y2  \
    $y3  \
    $y4  \
    --button=Применить!gtk-apply!"systemctl restart zramswap.service":0 \
    --button=!gtk-cancel!Отмена:1)
ret="$?"
#echo $ret "$yad_output" ;exit
[ $ret -eq 1 ] || [ $ret -eq 252 ]  &&   exit 0  # Пользователь отменил

# Разбираем вывод yad
algorithm=$(echo "$yad_output" | awk -F'|' '{print $1}')
memory_percent=$(echo "$yad_output" | awk -F'|' '{print $2}')
priority=$(echo "$yad_output" | awk -F'|' '{print $3}')

# Проверяем, что все поля заполнены
if [[ -z "$algorithm" || -z "$memory_percent" || -z "$priority" ]]; then
    yad --text="Пожалуйста, заполните все поля." --width=300 --height=100 --title="Ошибка"
    exit 1
fi

# Функция для создания конфигурации zram
create_zram_config() {
    local algorithm=$1
    local memory_percent=$2
    local priority=$3

    # Преобразуем memory_percent в целое число
    memory_percent=$(echo "$memory_percent" | sed 's/,/./')
    memory_percent=$(awk '{printf "%d", $1}' <<< "$memory_percent")

    # Редактируем конфигурационный файл
    sed -i "s/^#ALGO=.*/ALGO=$algorithm/" "$CONFIG_FILE"
    sed -i "s/^#PERCENT=.*/PERCENT=$memory_percent/" "$CONFIG_FILE"
    sed -i "s/^#PRIORITY=.*/PRIORITY=$priority/" "$CONFIG_FILE"

    sed -i "s/^ALGO=.*/ALGO=$algorithm/" "$CONFIG_FILE"
    sed -i "s/^PERCENT=.*/PERCENT=$memory_percent/" "$CONFIG_FILE"
    sed -i "s/^PRIORITY=.*/PRIORITY=$priority/" "$CONFIG_FILE"

    # Отображаем обновленную конфигурацию
    echo "Конфигурация для zram обновлена:"
    cat "$CONFIG_FILE"
}

# Создаем конфигурацию
create_zram_config "$algorithm" "$memory_percent" "$priority"

# Запуск службы zramswap
systemctl daemon-reload
[ $ret -eq 0 ] && systemctl restart zramswap.service
[ $ret -eq 2 ] && systemctl start   zramswap.service
[ $ret -eq 4 ] && systemctl stop    zramswap.service
[ $ret -eq 6 ] && systemctl enable  zramswap.service
[ $ret -eq 8 ] && systemctl disable zramswap.service
$0


exit
# Проверка статуса службы zramswap
if systemctl is-active --quiet zramswap.service; then
    status_message="Служба zramswap активирована."
else
    status_message="Служба zramswap не активирована."
fi

# Получение информации из zramctl
zram_info="$(/usr/sbin/zramctl)"

# Выводим статус службы и информацию zramctl в окно yad
yad --center --text="${status_message}\n\nИнформация zramctl:\n\n${zram_info}" \
    --title="Статус службы zramswap" --width=600 --height=400 --button="Закрыть:0"
